# matrix-appservice-kakaotalk - A Matrix-KakaoTalk puppeting bridge.
# Copyright (C) 2022 Tulir Asokan, Andrew Ferrazzutti
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
from typing import Optional

from attr import dataclass

from . import Attachment


@dataclass
class MediaKeyAttachment(Attachment):
    k: str
    url: str
    s: int


@dataclass
class PhotoAttachment(Attachment):
    w: int
    h: int
    thumbnailUrl: str
    thumbnailWidth: int
    thumbnailHeight: int
    cs: str
    mt: str


@dataclass
class MultiPhotoAttachment(Attachment):
    kl: list[str]
    wl: list[int]
    hl: list[int]
    csl: list[str]
    imageUrls: list[str]
    thumbnailUrls: list[str]
    thumbnailWidths: list[int]
    thumbnailHeights: list[int]
    sl: int


@dataclass
class VideoAttachment(Attachment):
    tk: str
    w: int
    h: int
    cs: str
    d: int


@dataclass
class FileAttachment(Attachment):
    name: str
    size: int
    expire: int
    cs: str


@dataclass
class AudioAttachment(Attachment):
    d: int
    expire: Optional[int] = None


@dataclass
class LongTextAttachment(Attachment):
    path: str
    k: str
    s: int
    sd: bool


__all__ = [
    "MediaKeyAttachment",
    "PhotoAttachment",
    "MultiPhotoAttachment",
    "VideoAttachment",
    "FileAttachment",
    "AudioAttachment",
    "LongTextAttachment",
]
